@@ -1,5 +1,4 @@
 from __future__ import annotations
-from tkinter import W
 from typing import Generator, List, Optional, Union, Callable, TYPE_CHECKING
 from uuid import uuid4
 from math import inf
@@ -83,51 +82,61 @@ class Actor:
             self.status.append("onhold")
 
         # schedule the actor onto timeline
-        if self.onhold is False:
+        if self.onhold is False and self.active is True:
             self.timeline.schedule(self)
 
     def perform(self):
         # non-continuous actor
-        if self.step is None and self.till is None:
-            if self.active:
+        if self.active:
+            if self.step is None and self.till is None:
                 self.action()
-        # continuous actor but misses step size
-        elif self.step is None and self.till is not None:
-            raise AttributeError(f"Actor {self.id} has no step size defined.")
-        # continuous actor with step size but no end time
-        elif self.step is not None and self.till is None:
-            self._till = inf
-            while self.time < self.till:
-                if self.active:
+                self.status.append("completed")
+            # continuous actor but misses step size
+            elif self.step is None and self.till is not None:
+                raise AttributeError(f"Actor {self.id} has no step size defined.")
+            # continuous actor with step size but no end time
+            elif self.step is not None and self.till is None:
+                self._till = inf
+                while self.time < self.till:
                     self.action()
-                if callable(self.step):
-                    self._time += self.step()
-                else:
-                    self._time += self.step
-                yield self.timeline.schedule(self)
-            if self.active:
+                    if callable(self.step):
+                        self._time += self.step()
+                    else:
+                        self._time += self.step
+                    yield self.timeline.schedule(self)
                 self.action()
-        # continuous actor with step size and end time
-        elif self.step is not None and self.till is not None:
-            if callable(self.till):
-                self._till = self.till()
-            while self.time < self.till:
-                if self.active:
+            # continuous actor with step size and end time
+            elif self.step is not None and self.till is not None:
+                if callable(self.till):
+                    self._till = self.till()
+                while self.time < self.till:
                     self.action()
-                if callable(self.step):
-                    self._time += self.step()
-                else:
-                    self._time += self.step
-                yield self.timeline.schedule(self)
-            if self.active:
+                    if callable(self.step):
+                        self._time += self.step()
+                    else:
+                        self._time += self.step
+                    yield self.timeline.schedule(self)
                 self.action()
+                self.status.append("completed")
 
     def deactivate(self):
-        if "active" in self.status:
+        if self.inactive:
+            return
+        else:
             self.status.remove("active")
-        if "inactive" not in self.status:
             self.status.append("inactive")
 
+    def activate(self):
+        if self.active:
+            return
+        else:
+            self.status.remove("inactive")
+            self.status.append("active")
+            self._time = self.timeline.now
+            self.timeline.schedule(self)
+
+
+
     def request(self, resource: Resource, amount: Union[int, float] = 1) -> bool:
         resource.distribute(self, amount)
 
